# Assests for examples and tests

The mesh files in this directory come from [MMG's tutorials](http://www.mmgtools.org/). They are used for testing and examples.

The assets files can be found in the [assets](https://github.com/kmarchais/mmgpy/tree/main/assets) directory of the repository.
